@@ -130,6 +130,16 @@ class PSFConfig(BaseModel):
     Ntheta = 40
     Nphi = 40
 
+    # Noise Parameters
+
+    gaussian_beam_noise = 0.0
+    detector_gaussian_noise = 0.0
+
+    add_detector_poisson_noise = False  # standard deviation of the noise
+
+    # Normalization
+    rescale = True  # rescale the PSF to have a maximum of 1
+
     @root_validator
     def validate_numerical_aperature(cls, values):
         numerical_aperature = values["numerical_aperature"]
